@@ -1,5 +1,4 @@
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
@@ -16,13 +15,10 @@ public:
     static Comment fromJson(const QJsonObject &, Comment &);
 
     QString author() const;
-    void setAuthor(const QString &name);
 
     QString authorAvatar() const;
-    void setAuthorAvatar(const QString &url);
 
     QString content() const;
-    void setContent(const QString &content);
 
 private:
     QString m_author;
